##  Before You Start
Knowing your IT landscape and achieving transparency is the first step before starting a rationalization initiative. You get transparency by going through the application portfolio assessment use case. After you have filled your inventory with the baseline information, you can start the application rationalization use case.
Ideally, you already have baseline information for the following data points:
  * Application's lifecycle
  * Business criticality
  * Functional and technical fit
  * Basic relations from applications to business capabilities and organizations in your inventory


If you’re missing this information in your inventory, go to the [Application Portfolio Assessment Use Case](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US "https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US").
### Required Products and Extensions
To start application rationalization, you need the following SAP LeanIX products and extensions:
  * SAP LeanIX Application Portfolio Managementfor building your data repository and conducting assessments for collecting IT landscape data and gaining insights
  * SAP LeanIX Architecture and Road Map Planning for adding Initiatives with Transformations and Impacts
  * The Application Total Cost of Ownership extension, if you have been an SAP LeanIX customer before July 2025 you need to activate the extension, newer customers have the changes all implemented into their workspace
